
=============================
:mod:`oujago.datatypes.queue`
=============================

.. automodule:: oujago.datatypes.queue

.. currentmodule:: oujago.datatypes


Detailed Description
--------------------


.. autoclass:: Queue
   :members:

